@@ -5,7 +5,7 @@ from carton.settings import CART_TEMPLATE_TAG_NAME
 
 register = template.Library()
 
-def get_cart(context, session_key=None, model=None, cart_class=Cart):
+def get_cart(context, session_key=None, product_model=None, cart_class=Cart):
     """
     Make the cart object available in template.
 
@@ -18,6 +18,6 @@ def get_cart(context, session_key=None, model=None, cart_class=Cart):
         {% endfor %}
     """
     request = context['request']
-    return cart_class(request.session, session_key=session_key, model=model)
+    return cart_class(request.session, session_key=session_key, product_model=product_model)
 
 register.assignment_tag(takes_context=True, name=CART_TEMPLATE_TAG_NAME)(get_cart)
